pub struct MemoryBuffer { /* private fields */ }Expand description
CPU-backed memory buffer metadata and storage.
Implementations
Sourceimpl MemoryBuffer
impl MemoryBuffer
Sourcepub fn as_slice(&self) -> &[u8] ⓘ
pub fn as_slice(&self) -> &[u8] ⓘ
Returns an immutable byte slice view over the whole allocation.
Sourcepub fn as_mut_slice(&mut self) -> &mut [u8] ⓘ
pub fn as_mut_slice(&mut self) -> &mut [u8] ⓘ
Returns a mutable byte slice view over the whole allocation.
Sourcepub fn as_ptr(&self) -> *const u8
pub fn as_ptr(&self) -> *const u8
Returns an immutable raw pointer to the beginning of the buffer.
Sourcepub fn as_mut_ptr(&mut self) -> *mut u8
pub fn as_mut_ptr(&mut self) -> *mut u8
Returns a mutable raw pointer to the beginning of the buffer.
Sourcepub fn strategy(&self) -> AllocationStrategy
pub fn strategy(&self) -> AllocationStrategy
Returns the allocation strategy used to create this buffer.